@@ -2,6 +2,7 @@ import traceback
 import psycopg2
 import pymssql
 import logging
+from decimal import Decimal
 import pandas as pd
 import time
 
@@ -68,7 +69,7 @@ class RDBService:
                 self.__connect()
             expressions=[]
             for key in update:
-                expressions.append("{}='{}'".format(key,self.__toValue(update[key])))
+                expressions.append("{}={}".format(key,self.__toValue(update[key])))
             update_str=",".join(expressions)
             sql = 'update {} set {} {}'.format(table,update_str,query)
             cusor = self.conn.cursor()
@@ -112,7 +113,7 @@ class RDBService:
 
 
     def __toValue(self, var):
-        if isinstance(var, int) or isinstance(var, float):
+        if isinstance(var, int) or isinstance(var, float) or isinstance(var,Decimal):
             return var
         else:
             return '\'{}\''.format(var)
